@@ -9,6 +9,7 @@
 #
 mysimpwd=`pwd`
 source ../../../libext/libext_utils/cmake.sh
+echo PATH is $PATH
 cd $mysimpwd
 if  [ -z "$(command -v python3)" ]; then
     echo python3 not installed
@@ -66,11 +67,11 @@ else
     VEC=scalar
 fi
 echo VEC $VEC
-if [[ "${VEC}" == "avx512" ]]; then
 if [[   -z "${CC}" ]]; then
     CC=cc
 fi
 echo CC is $CC
+if [[ "${VEC}" == "avx512" ]]; then
 GCC_EXTRA=$(echo $CC | cut -c 1-3)
 if [ "$GCC_EXTRA" == gcc ]; then
 let GCCVERSIONGT5=$(expr `${CC} -dumpversion | cut -f1 -d.` \> 5)
@@ -114,7 +115,7 @@ if [[ -z "${CMAKE}" ]]; then
 	get_cmake_release $cmake_instdir
 	status=$?
 	if [ $status -ne 0 ]; then
-	    echo cmake required to build scalapack
+	    echo cmake required to build simint
 	    echo Please install cmake
 	    echo define the CMAKE env. variable
 	    exit 1
@@ -126,12 +127,14 @@ fi
 CMAKE_VER_MAJ=$(${CMAKE} --version|cut -d " " -f 3|head -1|cut -d. -f1)
 CMAKE_VER_MIN=$(${CMAKE} --version|cut -d " " -f 3|head -1|cut -d. -f2)
 echo CMAKE_VER is ${CMAKE_VER_MAJ} ${CMAKE_VER_MIN}
-if ((CMAKE_VER_MAJ < 3)) || (((CMAKE_VER_MAJ > 2) && (CMAKE_VER_MIN < 21))); then
+if ((CMAKE_VER_MAJ < 3)) || (((CMAKE_VER_MAJ == 3) && (CMAKE_VER_MIN < 24))); then
     cmake_instdir=../../../libext/libext_utils/
     get_cmake_release $cmake_instdir
+    echo PATH is $PATH
+    echo @@@@
     status=$?
     if [ $status -ne 0 ]; then
-	echo cmake required to build scalapack
+	echo cmake 3.21 required to build simint
 	echo Please install cmake
 	echo define the CMAKE env. variable
 	exit 1
@@ -250,7 +253,9 @@ echo
 if [[ ! -z ${FFLAGS_FORGA} ]]; then Fortran_FLAGS+=" ${FFLAGS_FORGA}" ; fi
 echo Fortran_FLAGS equal "$Fortran_FLAGS"
 echo C_FLAGS equal "$C_FLAGS"
-FC="${FC}" CC="${CC}" CXX="${CXX}" $CMAKE \
+echo CMAKE is $CMAKE
+${CMAKE} --version
+FC="${FC}" CC="${CC}" CXX="${CXX}" CMAKE_POLICY_VERSION_MINIMUM=3.5 $CMAKE \
  -DCMAKE_BUILD_TYPE="${SIMINT_BUILD_TYPE}" -DSIMINT_VECTOR=${VEC}  \
  -DCMAKE_INSTALL_LIBDIR=lib -DENABLE_FORTRAN=ON -DSIMINT_MAXAM=${SIMINT_MAXAM} -DSIMINT_MAXDER=${DERIV} \
  -DENABLE_TESTS=OFF     -DSIMINT_STANDALONE=OFF   \
