@@ -1,4 +1,10 @@
 #!/usr/bin/env bash
+declare -a LIST_MPIFWRAP
+LIST_MPIFWRAP=( 'mpif90' 'mpifort' 'mpiifort' 'mpifc' 'mpixlf_r' 'mpixlf' 'mpif77' 'mpifrt' 'mpifrtpx' 'mpif90-mpich-mp' 'mpifort-mpich-mp' 'mpif90-openmpi-mp' 'mpifort-openmpi-mp')
+export LIST_MPIFWRAP
+declare -a LIST_MPICWRAP
+LIST_MPICWRAP=( 'mpicc' 'mpicc'    'mpiicc'  'mpiicc' 'mpixlc_r' 'mpixlc' 'mpicc' 'mpifcc' 'mpifccpx' 'mpicc-mpich-mp' 'mpicc-mpich-mp' 'mpicc-openmpi-mp' 'mpicc-openmpi-mp')
+export LIST_MPICWRAP
 myscalapwd=`pwd`
 source ../libext_utils/cmake.sh
 cd $myscalapwd
@@ -9,11 +15,25 @@ if [[ "$FC" = "ftn"  ]] ; then
     MPICC="cc"
 else
     if ! [ -x "$(command -v mpif90)" ]; then
-	echo
-	echo mpif90 not installed
-	echo mpif90 is required for building Scalapack
-	echo
-	exit 1
+	length=${#LIST_MPIFWRAP[*]}
+	indx=0
+	while [ "${indx}" -lt "${length}" ] ; do
+	    candidate="${LIST_MPIFWRAP[${indx}]}"
+	    CMDGUESS="$(command -v $candidate)"
+	    if [ $? -eq 0 ] ; then
+		MPIF90="${LIST_MPIFWRAP[${indx}]}"
+		MPICC="${LIST_MPICWRAP[${indx}]}"
+		echo found mpi wrappers $MPIF90 $MPICC
+		break
+	    else   ((indx++)); fi
+	done
+	if [ -z ${MPIF90} ] ; then
+	    echo
+	    echo mpif90 not installed
+	    echo mpif90 is required for building Scalapack
+	    echo
+	    exit 1
+	fi
     else
 	MPIF90="mpif90"
 	if [[ -z "${MPICC}" ]]; then
@@ -25,6 +45,9 @@ fi
 if [[  -z "${FC}" ]]; then
     FC=$($MPIF90 -show|cut -d " " -f 1)
 fi
+if [[  -z "${CC}" ]]; then
+    CC=$($MPICC -show|cut -d " " -f 1)
+fi
 if [[  -z "${NWCHEM_TOP}" ]]; then
     dir3=$(dirname `pwd`)
     dir2=$(dirname "$dir3")
@@ -55,6 +78,8 @@ if [[ -z "${CMAKE}" ]]; then
     if [[ -z "$(command -v cmake)" ]]; then
 	cmake_instdir=../libext_utils
 	get_cmake_release $cmake_instdir
+	echo PATH is $PATH
+	echo @@@@
 	status=$?
 	if [ $status -ne 0 ]; then
 	    echo cmake required to build scalapack
@@ -70,9 +95,11 @@ fi
 CMAKE_VER_MAJ=$(${CMAKE} --version|cut -d " " -f 3|head -1|cut -d. -f1)
 CMAKE_VER_MIN=$(${CMAKE} --version|cut -d " " -f 3|head -1|cut -d. -f2)
 echo CMAKE_VER is ${CMAKE_VER_MAJ} ${CMAKE_VER_MIN}
-if ((CMAKE_VER_MAJ < 3)) || (((CMAKE_VER_MAJ > 2) && (CMAKE_VER_MIN < 99))); then
+if ((CMAKE_VER_MAJ < 3)) || (((CMAKE_VER_MAJ == 3) && (CMAKE_VER_MIN < 24))); then
     cmake_instdir=../libext_utils
     get_cmake_release $cmake_instdir
+    echo PATH is $PATH
+    echo zzzz
     status=$?
     if [ $status -ne 0 ]; then
 	echo cmake required to build scalapack
@@ -119,6 +146,9 @@ VERSION=2.1.0
 #COMMIT=ea5d20668a6b8bbee645b7ffe44623c623969d33
 COMMIT=5bad7487f496c811192334640ce4d3fc5f88144b
 COMMIT=782e739f8eb0e7f4d51ad7dd23fc1d03dc99d240
+COMMIT=a23c2cdc6586c427686f6097ae66bb54ef693571
+#COMMIT=bd1768b91262b4cdc7dd5f87b373b9b18eda4636
+#COMMIT=b935167ca4d244735abc04a3cd4f6d56699702a0
 rm -rf scalapack 
 if [[ -f "scalapack-$COMMIT.tar.gz" ]]; then
     echo "using existing"  "scalapack-$COMMIT.tar.gz"
@@ -134,11 +164,12 @@ else
 		  tries=$((tries+1)) ;  done
 fi
 tar xzf scalapack-$COMMIT.tar.gz
-ln -sf scalapack-$COMMIT scalapack
+ln -sf scalapack-*$COMMIT scalapack
 #ln -sf scalapack-${VERSION} scalapack
 #curl -L http://www.netlib.org/scalapack/scalapack-${VERSION}.tgz -o scalapack.tgz
 #tar xzf scalapack.tgz
 cd scalapack
+patch -p1 < ../sca_cmake.patch
 # macos accelerate does not contain dcombossq
 if [[  ! -z "$USE_INTERNALBLAS" ]]; then
     export USE_DCOMBSSQ=1
@@ -150,7 +181,11 @@ fi
 if [[ $(echo "$LAPACK_LIB" |awk '/lapack/ {print "Y"; exit}' ) == "Y" ]]; then
     export USE_DCOMBSSQ=1
 fi
-if [[ $(echo ""$LAPACK_LIB |awk '/lfjlapack/ {print "Y"; exit}'  ) == "Y" ]]; then
+if [[ $(echo "$LAPACK_LIB" |awk '/lfjlapack/ {print "Y"; exit}'  ) == "Y" ]]; then
+    export USE_DCOMBSSQ=1
+fi
+# ubuntu 24.04 openblas pkg does not contain dcombossq
+if [[ $(echo "$LAPACK_LIB" |awk '/openblas/ {print "Y"; exit}'  ) == "Y" ]]; then
     export USE_DCOMBSSQ=1
 fi
 if [[  -z "$USE_DCOMBSSQ" ]]; then
@@ -209,7 +244,7 @@ if [[  -z "$MPICH_CC"   ]] ; then
     export MPICH_CC="$CC"
 fi
 echo MPICH_CC is "$MPICH_CC"
-echo $(mpicc -show)
+echo $(${MPICC} -show)
 #Intel MPI
 if [[  -z "$I_MPI_F90"   ]] ; then
     export I_MPI_F90="$FC"
@@ -235,11 +270,20 @@ fi
 GOTCLANG=$( "$MPICC" -dM -E - </dev/null 2> /dev/null |grep __clang__|head -1|cut -c19)
 if [[ `${MPICC} -dM -E - < /dev/null 2> /dev/null | grep -c GNU` > 0 ]] ; then
     let GCCVERSIONGT12=$(expr `${MPICC} -dumpversion | cut -f1 -d.` \> 12)
+    let GCCVERSIONGT13=$(expr `${MPICC} -dumpversion | cut -f1 -d.` \> 13)
+    let GCCVERSIONGT14=$(expr `${MPICC} -dumpversion | cut -f1 -d.` \> 14)
 fi
 
 if [[ ${GOTCLANG} == "1" ]] || [[ ${GCCVERSIONGT12} == "1" ]]  ; then
     C_FLAGS=" -Wno-error=implicit-function-declaration "
 fi
+if [[ ${GCCVERSIONGT13} == "1" ]]  ; then
+    C_FLAGS+=" -std=gnu17 "
+fi
+if [[ ${GCCVERSIONGT14} == "1" ]]  ; then
+    C_FLAGS+=" -fPIE "
+    Fortran_FLAGS+=" -fPIE "
+fi
 if [[  "$SCALAPACK_SIZE" == 8 ]] ; then
     if  [[ ${FC} == f95 ]] || [[ ${FC_EXTRA} == gfortran ]] ; then
     Fortran_FLAGS+=" -fdefault-integer-8 -w "
@@ -301,6 +345,9 @@ if [[ "$arch" == "i686" ]] || [[ "$arch" == "x86_64" ]]; then
 fi
 echo " $MPIF90 -show is " `$MPIF90 -show`
 echo LDFLAGS is $LDFLAGS
+echo CMAKE is $CMAKE
+echo cmake is $(which cmake)
+echo cmake V $(cmake --version)
 if [[ ${FC} == nvfortran ]] ; then
     echo compiling with CC="$MPICC"  FC=$FC MPIF90=$MPIF90 CFLAGS="$C_FLAGS" FFLAGS="$Fortran_FLAGS" $CMAKE -Wno-dev ../ -DCMAKE_BUILD_TYPE=MinSizeRel -DCMAKE_C_FLAGS="$C_FLAGS"  -DCMAKE_Fortran_FLAGS="$Fortran_FLAGS" -DTEST_SCALAPACK=OFF  -DBUILD_TESTING=OFF -DBUILD_SHARED_LIBS=OFF  -DBLAS_openblas_LIBRARY="$BLASOPT"  -DBLAS_LIBRARIES="$BLASOPT"  -DLAPACK_openblas_LIBRARY="$BLASOPT"  -DLAPACK_LIBRARIES="$BLASOPT" -DCMAKE_Fortran_FLAGS_RELWITHDEBINFO="-O2 -g -DNDEBUG  $Fortran_FLAGS"  $CMAKE_EXTRA  -DMPI_Fortran_COMPILE_OPTIONS="$Fortran_FLAGS"
     CC="$MPICC"  FC=$FC MPIF90=$MPIF90 CFLAGS="$C_FLAGS" FFLAGS="$Fortran_FLAGS" $CMAKE -Wdev ../ -DCMAKE_BUILD_TYPE=MinSizeRel -DCMAKE_C_FLAGS="$C_FLAGS"  -DCMAKE_Fortran_FLAGS="$Fortran_FLAGS" -DTEST_SCALAPACK=OFF  -DBUILD_TESTING=OFF -DBUILD_SHARED_LIBS=OFF  -DBLAS_openblas_LIBRARY="$BLASOPT"  -DBLAS_LIBRARIES="$BLASOPT"  -DLAPACK_openblas_LIBRARY="$BLASOPT"  -DLAPACK_LIBRARIES="$BLASOPT" -DCMAKE_Fortran_FLAGS_RELWITHDEBINFO="-O2 -g -DNDEBUG  $Fortran_FLAGS" $CMAKE_EXTRA -DMPI_Fortran_COMPILE_OPTIONS="$Fortran_FLAGS"
@@ -315,7 +362,13 @@ if [[ "$?" != "0" ]]; then
     cat $(find . -name *log)
     exit 1
 fi
-make V=0 -j3 scalapack/fast
+GOTFREEBSD=$(uname -o 2>&1|awk ' /FreeBSD/ {print "1";exit}')
+MYMAKE=make
+if [[  "${GOTFREEBSD}" == 1 ]]; then
+    MAKEJ="MAKE_NB_JOBS=1"
+    MYMAKE=gmake
+fi
+$MYMAKE V=0 -j3 scalapack/fast
 if [[ "$?" != "0" ]]; then
     echo " "
     echo "compilation failed"
