@@ -11,7 +11,7 @@
 #endif
 
 
-#if (defined(CRAY) || defined(WIN32))&& !defined(__crayx1) && !defined (__MINGW32__)
+#if (defined(CRAY) || defined(WIN32)) && !defined (__MINGW32__)
 #ifndef WIN32
 #define FATR
 #endif
