@@ -12,8 +12,12 @@ dist="ubuntu"
 arch=`uname -m`
 env | grep FC || true
 env | grep CC || true
+if [[ "$os" == "Darwin" ]]; then
+    IONEAPI_ROOT=~/apps/oneapi
+else
+    IONEAPI_ROOT=/opt/intel/oneapi
 if test -f "/usr/lib/os-release"; then
-    dist=$(grep ID= /etc/os-release |head -1 |cut -c4-| sed 's/\"//g')
+    dist=$(grep ID= /etc/os-release |grep -v VERSION |head -1 |cut -c4-| sed 's/\"//g')
 fi
 if test -f "/usr/lib/fedora-release"; then
     dist="fedora"
@@ -29,10 +33,6 @@ if [ -z "$DISTR" ] ; then
     DISTR=$dist
 fi
 echo DISTR is "$DISTR"
-if [[ "$os" == "Darwin" ]]; then
-    IONEAPI_ROOT=~/apps/oneapi
-else
-    IONEAPI_ROOT=/opt/intel/oneapi
 fi
 	if [[ "$os" == "Darwin" ]]; then
 	    if [ -z $XCODE_VERSION ]; then
@@ -43,21 +43,47 @@ fi
 		$MYSUDO xcode-select -s /Applications/Xcode_"$XCODE_VERSION".app/Contents/Developer
 	    fi
 #  HOMEBREW_NO_AUTO_UPDATE=1 brew cask uninstall oclint || true  
-#  HOMEBREW_NO_INSTALL_CLEANUP=1  HOMEBREW_NO_AUTO_UPDATE=1 brew install gcc "$MPI_IMPL" openblas python3 ||true
-     HOMEBREW_NO_INSTALL_CLEANUP=1  HOMEBREW_NO_AUTO_UPDATE=1 brew reinstall gcc "$MPI_IMPL" gsed grep automake autoconf ||true
+	    #  HOMEBREW_NO_INSTALL_CLEANUP=1  HOMEBREW_NO_AUTO_UPDATE=1 brew install gcc "$MPI_IMPL" openblas python3 ||true
+	    HOMEBREW_NO_INSTALL_CLEANUP=1  HOMEBREW_NO_AUTO_UPDATE=1 brew reinstall gcc hwloc  gsed grep automake autoconf  ||true
+	    if [[ "$MPI_IMPL" != "build_mpich" ]]; then
+		brew list open-mpi >&  /dev/null ; myexit=$?
+		if [[ $myexit == 0 ]]; then HOMEBREW_NO_INSTALL_CLEANUP=1  HOMEBREW_NO_AUTO_UPDATE=1 brew unlink -q open-mpi ||true ; fi
+                brew list mpich >&  /dev/null ; myexit=$?
+		if [[ $myexit == 0 ]]; then HOMEBREW_NO_INSTALL_CLEANUP=1  HOMEBREW_NO_AUTO_UPDATE=1 brew unlink -q mpich ||true ; fi
+		HOMEBREW_NO_INSTALL_CLEANUP=1  HOMEBREW_NO_AUTO_UPDATE=1 brew reinstall  $MPI_IMPL  ||true
+#		HOMEBREW_NO_INSTALL_CLEANUP=1  HOMEBREW_NO_AUTO_UPDATE=1 brew link --overwrite $MPI_IMPL ||true
+	    fi
+     if [ -z "$HOMEBREW_CELLAR" ] ; then
+	 HOMEBREW_CELLAR=/usr/local/Cellar
+     fi
      if [[ "$FC" != "gfortran" ]] && [[ "$FC" == "gfortran*" ]]; then
 	 #install non default gfortran, ie gfortran-9
 	 #get version
 	 mygccver=$(echo "$FC"|cut -d - -f 2)
 	 echo mygccver is "$mygccver"
 	 HOMEBREW_NO_INSTALL_CLEANUP=1  HOMEBREW_NO_AUTO_UPDATE=1 brew reinstall gcc@"$mygccver" || true
+	 export PATH=$HOMEBREW_CELLAR/../opt/gcc@"$mygccver"/bin:$PATH
+	 echo gfortran is $(gfortran -v)
+	 echo gfortran-"$mygccver" is $(gfortran-"$mygccver" -v)
+     fi
+     if [[ "$FC" == "flang" ]]; then
+	 echo installing flang
+	 HOMEBREW_NO_INSTALL_CLEANUP=1  HOMEBREW_NO_AUTO_UPDATE=1 brew install flang || true
+	 echo flang is $(flang --version)
+     fi
+     if [[ "$CC" != gcc ]] && [[ "$CC" == gcc* ]]; then
+	 #install non default gfortran, ie gcc-9
+	 #get version
+	 mygccver=$(echo "$CC"|cut -d - -f 2)
+	 echo mygccver is "$mygccver"
+	 HOMEBREW_NO_INSTALL_CLEANUP=1  HOMEBREW_NO_AUTO_UPDATE=1 brew reinstall gcc@"$mygccver" || true
+	 export PATH=$HOMEBREW_CELLAR/../opt/gcc@"$mygccver"/bin:$PATH
+	 echo gcc is $(gcc -v)
+	 echo gcc-"$mygccver" is $(gcc-"$mygccver" -v)
      fi
      #hack to fix Github actions mpif90
      gccver=`brew list --versions gcc| head -1 |cut -c 5-`
      echo brew gccver is $gccver
-     if [ -z "$HOMEBREW_CELLAR" ] ; then
-	 HOMEBREW_CELLAR=/usr/local/Cellar
-     fi
      ln -sf $HOMEBREW_CELLAR/gcc/$gccver/bin/gfortran-* $HOMEBREW_CELLAR/gcc/$gccver/bin/gfortran || true
      ln -sf $HOMEBREW_CELLAR/gcc/$gccver/bin/gfortran-* /usr/local/bin/gfortran || true
      #	 ln -sf /usr/local/bin/$FC /usr/local/bin/gfortran
@@ -103,22 +129,33 @@ fi
 	"$FC" -V
 	icc -V
      fi
-     if [[ "$MPI_IMPL" == "mpich" ]]; then
-	 #         brew install mpich && brew upgrade mpich && brew unlink openmpi && brew unlink mpich && brew link --overwrite  mpich ||true
-	 brew update || true
-	 brew list open-mpi >&  /dev/null ; myexit=$?
-	 if [[ $myexit == 0 ]]; then brew unlink open-mpi || true ; fi
-	 brew reinstall mpich && brew upgrade mpich  && brew link --overwrite  mpich || true
+#     if [[ "$MPI_IMPL" == "mpich" ]]; then
+#	 #         brew install mpich && brew upgrade mpich && brew unlink openmpi && brew unlink mpich && brew link --overwrite  mpich ||true
+#	 brew update || true
+#	 brew list open-mpi >&  /dev/null ; myexit=$?
+#	 if [[ $myexit == 0 ]]; then brew unlink open-mpi || true ; fi
+#	 brew reinstall --quiet mpich  && brew unlink mpich && brew link mpich || true
+###	 brew reinstall --quiet mpich || true
+#     fi
+     if [ -z "$HOMEBREW_PREFIX" ] ; then
+	 HOMEBREW_PREFIX=/usr/local
+     fi
+     if [[ "$MPI_IMPL" != "build_mpich" ]]; then
+	 #check mpi install
+	 if [[ "$MPI_IMPL" == "mpich" ]]; then
+	     export MPICH_FC=$FC
+	     echo 'mpi90 -show' $("$HOMEBREW_PREFIX"/opt/mpich/bin/mpif90 -show)
+	 fi
+	 if [[ "$MPI_IMPL" == "openmpi" ]]; then
+	     echo 'mpif90 -show' $("$HOMEBREW_PREFIX"/opt/open-mpi/bin/mpif90 -show)
+	 fi
      fi
      if [[ "$BLAS_ENV" == "brew_openblas" ]]; then
 	 brew install openblas
-	 if [ -z "$HOMEBREW_PREFIX" ] ; then
-	     HOMEBREW_PREFIX=/usr/local
-	 fi
 	 PKG_CONFIG_PATH=$HOMEBREW_PREFIX/opt/openblas/lib/pkgconfig pkg-config --libs openblas
      fi
 #  if [[ "$MPI_IMPL" == "openmpi" ]]; then
-#      HOMEBREW_NO_INSTALL_CLEANUP=1 HOMEBREW_NO_AUTO_UPDATE=1 brew install scalapack
+#      HOMEBREW_NO_INSTALL_CLEANUP=1 HOMEBREW_NO_AUTO_UPDATE=1 brew install --quiet scalapack
 #  fi
 fi
 if [[ "$os" == "Linux" ]]; then
@@ -146,6 +183,12 @@ if [[ "$os" == "Linux" ]]; then
 	which mpif90
 	mpif90 -show
     else
+       #fix for MPICH on ubuntu 24.04
+	if [[ "$MPI_IMPL" == "mpich" ]] && [[ "$DISTR" == "ubuntu" ]]; then
+	    ubuntu_v=$(grep VERSION_ID /etc/os-release|cut -d = -f 2 | sed 's/\"//g' )
+	    if [ $ubuntu_v = "24.04" ]; then export MPI_IMPL="build_mpich"; export BUILD_MPICH=1 ; fi
+	fi
+
 	if [[ "$MPI_IMPL" == "openmpi" ]]; then
 	    mpi_bin="openmpi-bin" ; mpi_libdev="libopenmpi-dev" scalapack_libdev="libscalapack-openmpi-dev"
 	fi
@@ -160,7 +203,7 @@ if [[ "$os" == "Linux" ]]; then
 	    $MYSUDO apt-get update
 
 	    if [[ "$MPI_IMPL" == "intel" ]]; then
-		mpi_bin="  " ; mpi_libdev=" " scalapack_libdev=" "
+		mpi_bin="intel-oneapi-mpi" ; mpi_libdev="intel-oneapi-mpi-devel" scalapack_libdev=" "
 	    fi
 	fi
 	if [[ "$GITHUB_WORKFLOW" != "NWChem_CI_selfhosted" ]]; then
@@ -186,7 +229,7 @@ if [[ "$os" == "Linux" ]]; then
 
 	fi
 	if [[ "$FC" == "ifort" ]] || [[ "$FC" == "ifx" ]]; then
-	    $MYSUDO apt-get install -y intel-oneapi-compiler-fortran intel-oneapi-mkl intel-oneapi-compiler-dpcpp-cpp
+	    $MYSUDO apt-get install -y intel-oneapi-compiler-fortran intel-oneapi-mkl intel-oneapi-compiler-dpcpp-cpp  libfabric-bin libnuma1
 	    if [[ "$?" != 0 ]]; then
 		df -h
 		echo "intel-oneapi-compiler-fortran install failed: exit code " "${?}"
@@ -196,70 +239,46 @@ if [[ "$os" == "Linux" ]]; then
 	    export I_MPI_F90="$FC"
 	    "$FC" -V ; if [[ $? != 0 ]]; then echo "Intel SW install failed"; exit 1; fi
 	    icx -V
-	    sudo rm -rf $MKLROOT/lib/*sycl* || true
+	    $MYSUDO rm -rf $MKLROOT/lib/*sycl* || true
 	fi
-	if [[ "$FC" == 'flang-new-'* ]]; then
+	if [[ "$FC" == 'flang-new-'* || "$FC" == 'flang-'?? ]]; then
 	    wget https://apt.llvm.org/llvm.sh
 	    chmod +x llvm.sh
-	    llvm_ver=$(echo $FC | cut -d - -f 3)
+	    llvm_ver=$(echo "${FC##*-}")
 	    $MYSUDO ./llvm.sh $llvm_ver
 	    $MYSUDO apt-get install -y flang-$llvm_ver
 	fi
-	if [[ "$FC" == "flang" ]]; then
-	    if [[ "USE_AOMP" == "Y" ]]; then
-		aomp_major=19
-		aomp_minor=0-3
-		wget -nv https://github.com/ROCm-Developer-Tools/aomp/releases/download/rel_"$aomp_major"."$aomp_minor"/aomp_Ubuntu2004_"$aomp_major"."$aomp_minor"_amd64.deb
-		$MYSUDO dpkg -i aomp_Ubuntu2004_"$aomp_major"."$aomp_minor"_amd64.deb
-		export PATH=/usr/lib/aomp_"$aomp_major"."$aomp_minor"/bin/:$PATH
-		export LD_LIBRARY_PATH=/usr/lib/aomp_"$aomp_major"."$aomp_minor"/lib:$LD_LIBRARY_PATH
-		ls -lrt /usr/lib | grep aomp ||true
-	    else
-		aocc_major=4
-		aocc_minor=1
-		aocc_patch=0
-		aocc_version=${aocc_major}.${aocc_minor}.${aocc_patch}
-		aocc_dir=aocc-${aocc_major}-${aocc_minor}
-		aocc_file=aocc-compiler-${aocc_version}
-#		curl -sS -LJO https://developer.amd.com/wordpress/media/files/${aocc_dir}.tar
-		tries=0 ; until [ "$tries" -ge 10 ] ; do \
-                curl -sS -LJO https://download.amd.com/developer/eula/aocc/${aocc_dir}/${aocc_file}.tar \
-                && break ; \
-                tries=$((tries+1)) ; echo attempt no.  $tries    ; sleep 30 ;  done
-		tar xf ${aocc_file}.tar
-		./${aocc_file}/install.sh
-		source setenv_AOCC.sh
-		pwd
-	    fi
-	    flang -v
-	    which flang
-	fi
 	if [[ "$FC" == "amdflang" ]]; then
 	    $MYSUDO apt-get install -y wget gnupg2 coreutils dialog tzdata
-	    rocm_version=5.6.1
-	    tries=0 ; until [ "$tries" -ge 10 ] ; do \
-	    wget -q -O - https://repo.radeon.com/rocm/rocm.gpg.key |  $MYSUDO apt-key add - \
-		&& break ; \
-	    tries=$((tries+1)) ; echo attempt no.  $tries    ; sleep 30 ; done
-	    echo 'deb [arch=amd64] https://repo.radeon.com/rocm/apt/'$rocm_version'/ ubuntu main' | $MYSUDO tee /etc/apt/sources.list.d/rocm.list
+	    $MYSUDO mkdir --parents --mode=0755 /etc/apt/keyrings
+	    rocm_version=7.0.1
+#	    tries=0 ; until [ "$tries" -ge 10 ] ; do \
+#	    wget -q -O - https://repo.radeon.com/rocm/rocm.gpg.key | gpg --dearmor |  $MYSUDO tee /etc/apt/keyrings/rocm.gpg > /dev/null \
+#		&& break ; \
+#	    tries=$((tries+1)) ; echo attempt no.  $tries    ; sleep 30 ; done
+	    $MYSUDO gpg --no-tty --keyserver hkp://keyserver.ubuntu.com:80  --recv-keys 9386B48A1A693C5C
+	    $MYSUDO gpg --no-tty --export --armor 9386B48A1A693C5C | $MYSUDO gpg --no-tty --dearmor -o  /etc/apt/keyrings/rocm.gpg
+	    echo 'deb [arch=amd64 signed-by=/etc/apt/keyrings/rocm.gpg] https://repo.radeon.com/rocm/apt/'$rocm_version'/ jammy main' | $MYSUDO tee /etc/apt/sources.list.d/rocm.list
 	    tries=0 ; until [ "$tries" -ge 10 ] ; do \
 	    $MYSUDO apt-get  update -y && $MYSUDO apt-get -y install rocm-llvm openmp-extras \
             && break ; \
 	    tries=$((tries+1)) ; echo attempt no.  $tries    ; sleep 30 ; done
+	    $MYSUDO update-alternatives --install /opt/rocm rocm /opt/rocm-$rocm_version 100
+	    $MYSUDO update-alternatives --set rocm /opt/rocm-$rocm_version
 	    export PATH=/opt/rocm/bin:$PATH
 	    export LD_LIBRARY_PATH=/opt/rocm/lib:/opt/rocm/llvm/lib:$LD_LIBRARY_PATH
-	    amdflang -v ; if [[ $? != 0 ]]; then echo "amdflang install failed"; exit 1; fi
-	    amdclang -v
+	    amdflang --version ; if [[ $? != 0 ]]; then echo "amdflang install failed"; exit 1; fi
+	    amdclang --version
 	fi
 	if [[ "$FC" == "nvfortran" ]]; then
 	    $MYSUDO apt-get -y install lmod g++ libtinfo5 libncursesw5 lua-posix lua-filesystem lua-lpeg lua-luaossl
-	    nv_major=23
-	    nv_minor=7
+	    nv_major=25
+	    nv_minor=9
 	    nverdot="$nv_major"."$nv_minor"
 	    nverdash="$nv_major"-"$nv_minor"
 	    arch_dpkg=`dpkg --print-architecture`
-	    curl https://developer.download.nvidia.com/hpc-sdk/ubuntu/DEB-GPG-KEY-NVIDIA-HPC-SDK | sudo gpg --yes --dearmor -o /usr/share/keyrings/nvidia-hpcsdk-archive-keyring.gpg
-            echo 'deb [signed-by=/usr/share/keyrings/nvidia-hpcsdk-archive-keyring.gpg] https://developer.download.nvidia.com/hpc-sdk/ubuntu/'$arch_dpkg' /' | sudo tee /etc/apt/sources.list.d/nvhpc.list
+	    curl https://developer.download.nvidia.com/hpc-sdk/ubuntu/DEB-GPG-KEY-NVIDIA-HPC-SDK | $MYSUDO gpg --yes --dearmor -o /usr/share/keyrings/nvidia-hpcsdk-archive-keyring.gpg
+            echo 'deb [signed-by=/usr/share/keyrings/nvidia-hpcsdk-archive-keyring.gpg] https://developer.download.nvidia.com/hpc-sdk/ubuntu/'$arch_dpkg' /' | $MYSUDO tee /etc/apt/sources.list.d/nvhpc.list
 	    echo '*** added hpc-sdk source to /etc/aps ***'
 	    ls -lrt /etc/apt/sources.list.d/ || true
 	    ls -lrt	/etc/apt/sources.list.d/nvhpc.list || true
@@ -277,6 +296,8 @@ if [[ "$os" == "Linux" ]]; then
 	    $MYSUDO rm -rf /opt/nvidia/hpc_sdk/Linux_"$arch"/"$nverdot"/profilers
 	    $MYSUDO rm -rf /opt/nvidia/hpc_sdk/Linux_"$arch"/"$nverdot"/comm_libs
 	    $MYSUDO rm -rf /opt/nvidia/hpc_sdk/Linux_"$arch"/"$nverdot"/math_libs
+	    $MYSUDO ln -sf /opt/nvidia/hpc_sdk/Linux_"$arch"/"$nverdot" /opt/nvidia/hpc_sdk/Linux_"$arch"/latest
+	    ls -lrt /opt/nvidia/hpc_sdk/Linux_"$arch"/latest/
 	    export FC=nvfortran
 	    export CC=gcc
 	    nvfortran -V ;if [[ $? != 0 ]]; then echo "nvfortran install failed"; exit 1; fi
@@ -284,14 +305,16 @@ if [[ "$os" == "Linux" ]]; then
 	fi
     fi
     # check for mpif90 command and exit if not present
+    if [[ "$MPI_IMPL" != "build_mpich" ]]; then
     if [[ ! $(command -v mpif90) ]]; then echo "mpif90 not present"; exit 1; fi
     echo "mpif90 -show output is " `mpif90 -show` || true
     echo "which mpif90 output is " `which mpif90` ||  true
+    fi
 # try to use ubuntu flaky GA pkg 
     if [[ "$ARMCI_NETWORK" == "GA_DEBIAN" ]]; then
 	$MYSUDO apt-get install -y libglobalarrays-dev libarmci-mpi-dev
-	# hack
-	$MYSUDO ln -sf /usr/lib/x86_64-linux-gnu/libarmci.a /usr/lib/x86_64-linux-gnu/libarmci-openmpi.a
+#	# hack
+#	$MYSUDO ln -sf /usr/lib/x86_64-linux-gnu/libarmci.a /usr/lib/x86_64-linux-gnu/libarmci-openmpi.a
 #    export EXTERNAL_GA_PATH=/usr/lib/x86_64-linux-gnu/ga/openmpi
 #	export EXTERNAL_GA_PATH=/usr
 #	export EXTERNAL_ARMCI_PATH=/usr
