@@ -35,13 +35,13 @@ if [[ ! -z "$USE_OPENMP" ]]; then
     export OMP_NUM_THREADS="$USE_OPENMP"
     export OMP_STACKSIZE=32M
 fi
-if [[ "$arch" == "aarch64" ]] || [[ "$os" == "Darwin" &&   "$BUILD_MPICH" == 1 ]] || [[ "$os" == "Darwin" && "$ARMCI_NETWORK" == MPI-PT ]]   ; then
+if [[ "$os" == "Darwin" && "$ARMCI_NETWORK" == MPI-PT ]]   ; then
     nprocs=1
 fi    
 env|egrep MP
  do_largeqas=1
 
- if [[ "$EXTRA_BUILD" == "1" ]] || [[ ! -z "$USE_SIMINT" ]] || [[ "$arch" == "aarch64" ]] || [[ "$arch" == "ppc64le" ]] || [[ "$arch" == "riscv64" ]]; then
+ if [[ "$CACHE_HIT" == "N" ]] || [[ "$EXTRA_BUILD" == "1" ]] || [[ ! -z "$USE_SIMINT" ]] ||  [[ "$arch" == "ppc64le" ]] || [[ "$arch" == "riscv64" ]]; then
      do_largeqas=0
  fi
 
@@ -51,6 +51,9 @@ env|egrep MP
  if [[ "$os" == "Darwin" && "NWCHEM_MODULES" == "tce" ]]; then
     do_largeqas=0
  fi
+ if [[ "$os" == "Darwin" && "$FC" == "flang" ]]; then
+    do_largeqas=0
+ fi
  if [[ ! -z "$USE_INTERNALBLAS" ]]; then
     do_largeqas=0
  fi
@@ -88,14 +91,27 @@ env|egrep MP
 		;;
 	esac
 	;;
+    ARMCI)
+        case "$os" in
+# fixes segfault for bse_ethene in ga_copy_patch...ARMCII_Iov_op_datatype
+            Linux)
+                ulimit -s unlimited
+		;;
+	esac
+	;;
  esac
 if [[ "$MPI_IMPL" == "openmpi" ]]; then
 export MPIRUN_NPOPT=" --allow-run-as-root -mca mpi_yield_when_idle 0 --oversubscribe -np "
 fi
+if [[ "$MPI_IMPL" == "intel" ]]; then
+#to avoid segfault with FI_PROVIDER=shm in MPI_Finalize with Intel MPI 2021.15
+export FI_PROVIDER=tcp
+fi
 if [[ -d "$TRAVIS_BUILD_DIR/.cachedir/files/libraries" ]]; then
  echo === ls binaries cache ===
  ls -lrt $TRAVIS_BUILD_DIR/.cachedir/binaries/$NWCHEM_TARGET/ || true
 fi
+ echo do_largeqas "$do_largeqas"
  echo =========================
  if [[ -z "$TRAVIS_HOME" ]]; then
      echo 'no using sleep loop'
@@ -120,11 +136,20 @@ fi
 	 fi
 	 if [[ ! $(grep -i cosmo $TRAVIS_BUILD_DIR/src/stubs.F| awk '/cosmo_input/') ]]; then
 	     cd $TRAVIS_BUILD_DIR/QA && ./runtests.mpi.unix procs $nprocs cosmo_h2o_dft
+	     if  [[ "$do_largeqas" == 1 ]]; then
+		 cd $TRAVIS_BUILD_DIR/QA && ./runtests.mpi.unix procs $nprocs cosmo_h2cco2_opt
+	     fi
 	 fi
          if [[ ! $(grep -i gw $TRAVIS_BUILD_DIR/src/stubs.F| awk '/gw_input/') ]]; then
   	     cd $TRAVIS_BUILD_DIR/QA && ./runtests.mpi.unix procs $nprocs ritddft_h2o ritddft_co
              cd $TRAVIS_BUILD_DIR/QA && NWCHEM_BASIS_LIBRARY=${NWCHEM_TOP}/src/basis/libraries.bse/ ./runtests.mpi.unix procs $nprocs gw_closedshell gw_openshell gw_symmetry
          fi
+         if [[ ! $(grep -i bse $TRAVIS_BUILD_DIR/src/stubs.F| awk '/bse_input/') ]]; then
+             cd $TRAVIS_BUILD_DIR/QA && ./runtests.mpi.unix procs $nprocs bse_ethene
+         fi
+         if [[ ! $(grep -i dplot $TRAVIS_BUILD_DIR/src/stubs.F| awk '/dplot_input/') ]]; then
+  	     cd $TRAVIS_BUILD_DIR/QA && ./runtests.mpi.unix procs $nprocs rt_tddft_dplot
+	 fi
      else
 	 echo ' dft_input stubbed'
      fi
@@ -164,8 +189,10 @@ fi
 	     cd $TRAVIS_BUILD_DIR/QA && ./runtests.mpi.unix procs $nprocs x2c-h2se
 	     cd $TRAVIS_BUILD_DIR/QA && ./runtests.mpi.unix procs $nprocs dftd3_c6cn
 	     cd $TRAVIS_BUILD_DIR/QA && ./runtests.mpi.unix procs $nprocs xe-zora-mp-so
+	     cd $TRAVIS_BUILD_DIR/QA && ./runtests.mpi.unix procs $nprocs oniom2
 	   if [[ ! -z "$USE_LIBXC" ]] || [[ ! -z "$LIBXC_INCLUDE" ]]; then
 	       cd $TRAVIS_BUILD_DIR/QA && ./runtests.mpi.unix procs $nprocs libxc_he2+
+	       cd $TRAVIS_BUILD_DIR/QA && ./runtests.mpi.unix procs $nprocs libxc_scanl
 	   fi
 	   if [[ ! -z "$BUILD_ELPA" ]]; then
 	       cd $TRAVIS_BUILD_DIR/QA && ./runtests.mpi.unix procs $nprocs dft_siosi3_elpa
